@@ -60,21 +60,21 @@
 #' # cleanup
 #' setwd(oldwd)
 #' unlink(repo, recursive = TRUE)
-git_commit <- function(message, author = NULL, committer = NULL, repo = '.'){
+git_commit <- function(message, author = NULL, committer = NULL, repo = '.') {
   repo <- git_open(repo)
-  if(!length(author)) {
+  if (!length(author)) {
     author <- git_signature_default(repo = repo)
   } else {
     git_signature_parse(author) #validate
   }
-  if(!length(committer)){
+  if (!length(committer)) {
     committer <- author
   } else {
-    git_signature_parse(committer)  #validate
+    git_signature_parse(committer) #validate
   }
   stopifnot(is.character(message), length(message) == 1)
   status <- git_status(repo = repo)
-  if(!any(status$staged))
+  if (!any(status$staged))
     stop("No staged files to commit. Run git_add() to select files.")
   merge_parents <- git_merge_parent_heads(repo = repo)
   .Call(R_git_commit_create, repo, message, author, committer, merge_parents)
@@ -82,25 +82,35 @@ git_commit <- function(message, author = NULL, committer = NULL, repo = '.'){
 
 #' @export
 #' @rdname git_commit
-git_commit_all <- function(message, author = NULL, committer = NULL, repo = '.'){
+git_commit_all <- function(
+  message,
+  author = NULL,
+  committer = NULL,
+  repo = '.'
+) {
   repo <- git_open(repo)
   unstaged <- git_status(staged = FALSE, repo = repo)
 
-  changes <- unstaged$file[unstaged$status %in% c("modified", "renamed", "typechange")]
-  if(length(changes))
-    git_add(changes, repo = repo)
+  changes <- unstaged$file[
+    unstaged$status %in% c("modified", "renamed", "typechange")
+  ]
+  if (length(changes)) git_add(changes, repo = repo)
 
   deleted <- unstaged$file[unstaged$status == "deleted"]
-  if(length(deleted))
-    git_rm(deleted, repo = repo)
+  if (length(deleted)) git_rm(deleted, repo = repo)
 
-  git_commit(message = message, author = author, committer = committer, repo = repo)
+  git_commit(
+    message = message,
+    author = author,
+    committer = committer,
+    repo = repo
+  )
 }
 
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_commit_info
-git_commit_info <- function(ref = "HEAD", repo = '.'){
+git_commit_info <- function(ref = "HEAD", repo = '.') {
   repo <- git_open(repo)
   .Call(R_git_commit_info, repo, ref)
 }
@@ -108,16 +118,24 @@ git_commit_info <- function(ref = "HEAD", repo = '.'){
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_commit_id
-git_commit_id <- function(ref = "HEAD", repo = '.'){
+git_commit_id <- function(ref = "HEAD", repo = '.') {
   repo <- git_open(repo)
   .Call(R_git_commit_id, repo, ref)
 }
 
+#' @export
+#' @rdname git_commit
+#' @useDynLib gert R_git_commit_stats
+git_commit_stats <- function(ref = "HEAD", repo = '.') {
+  repo <- git_open(repo)
+  .Call(R_git_commit_stats, repo, ref)
+}
+
 #' @export
 #' @rdname git_commit
 #' @param ancestor a reference to a potential ancestor commit
 #' @useDynLib gert R_git_commit_descendant
-git_commit_descendant_of <- function(ancestor, ref = 'HEAD', repo = '.'){
+git_commit_descendant_of <- function(ancestor, ref = 'HEAD', repo = '.') {
   repo <- git_open(repo)
   .Call(R_git_commit_descendant, repo, ref, ancestor)
 }
@@ -128,7 +146,7 @@ git_commit_descendant_of <- function(ancestor, ref = 'HEAD', repo = '.'){
 #' Use `"."` to stage all changed files.
 #' @param force add files even if in gitignore
 #' @useDynLib gert R_git_repository_add
-git_add <- function(files, force = FALSE, repo = '.'){
+git_add <- function(files, force = FALSE, repo = '.') {
   repo <- git_open(repo)
   info <- git_info(repo)
   normalizePath(file.path(info$path, files), mustWork = FALSE)
@@ -140,7 +158,7 @@ git_add <- function(files, force = FALSE, repo = '.'){
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_repository_rm
-git_rm <- function(files, repo = '.'){
+git_rm <- function(files, repo = '.') {
   repo <- git_open(repo)
   info <- git_info(repo)
   normalizePath(file.path(info$path, files), mustWork = FALSE)
@@ -153,17 +171,19 @@ git_rm <- function(files, repo = '.'){
 #' @useDynLib gert R_git_status_list
 #' @param staged return only staged (TRUE) or unstaged files (FALSE).
 #' Use `NULL` or `NA` to show both (default).
-git_status <- function(staged = NULL, repo = '.'){
+#' @param pathspec character vector with paths to match
+git_status <- function(staged = NULL, pathspec = NULL, repo = '.') {
   repo <- git_open(repo)
   staged <- as.logical(staged)
-  df <- .Call(R_git_status_list, repo, staged)
-  df[order(df$file), ,drop = FALSE]
+  pathspec <- as.character(pathspec)
+  df <- .Call(R_git_status_list, repo, staged, pathspec)
+  df[order(df$file), , drop = FALSE]
 }
 
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_conflict_list
-git_conflicts <- function(repo = '.'){
+git_conflicts <- function(repo = '.') {
   repo <- git_open(repo)
   .Call(R_git_conflict_list, repo)
 }
@@ -171,9 +191,12 @@ git_conflicts <- function(repo = '.'){
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_repository_ls
-git_ls <- function(repo = '.'){
+git_ls <- function(repo = '.', ref = NULL) {
   repo <- git_open(repo)
-  .Call(R_git_repository_ls, repo)
+  if (!length(ref) && isTRUE(git_info(repo = repo)$bare)) {
+    ref <- 'HEAD'
+  }
+  .Call(R_git_repository_ls, repo, ref = ref)
 }
 
 #' @export
@@ -182,25 +205,24 @@ git_ls <- function(repo = '.'){
 #' @param ref revision string with a branch/tag/commit value
 #' @param max lookup at most latest n parent commits
 #' @param after date or timestamp: only include commits starting this date
-git_log <- function(ref = "HEAD", max = 100, after = NULL, repo = "."){
+git_log <- function(ref = "HEAD", max = 100, after = NULL, repo = ".") {
   repo <- git_open(repo)
   ref <- as.character(ref)
   max <- as.integer(max)
-  if(length(after))
-    after <- as.POSIXct(after)
+  if (length(after)) after <- as.POSIXct(after)
   .Call(R_git_commit_log, repo, ref, max, after)
 }
 
 #' @export
 #' @rdname git_commit
 #' @useDynLib gert R_git_stat_files
-git_stat_files <- function(files, ref = "HEAD", repo = '.'){
+git_stat_files <- function(files, ref = "HEAD", repo = '.') {
   repo <- git_open(repo)
   files <- as.character(files)
   .Call(R_git_stat_files, repo, files, ref)
 }
 
-assert_string <- function(x){
-  if(!is.character(x) || !length(x))
+assert_string <- function(x) {
+  if (!is.character(x) || !length(x))
     stop("Argument must be a string of length 1")
 }
